package de.uniulm.mathematik.typo.items;

import java.util.*;
import de.uniulm.mathematik.typo.fonts.*;

/**
 * Represent items with a surrounding invisible border.
 */
public class BorderedItem extends DelegatingItem {
   private int border;

   /**
    * Construct an item that delegates all methods to item but
    * extends the geometry such that a border of the given width
    * is added.
    * @param item the item that is to be wrapped by a border.
    * @param border the thickness of the border in units (1/1000 points).
    *               This value must be non-negative.
    */
   public BorderedItem(Item item, int border) {
      super(item);
      assert(border >= 0);
      this.border = border;
   }

   /**
    * Return the width of the enlarged item, i.e. the original width
    * plus two times the thickness of the border.
    */
   public int getWidth() {
      return item.getWidth() + 2 * border;
   }

   /**
    * Return the height of the item, i.e. the original height
    * plus the thickness of the border.
    */
   public int getHeight() {
      return item.getHeight() + border;
   }

   /**
    * Return the depth of the item, i.e. the original depth
    * plus the thickness of the border.
    */
   public int getDepth() {
      return item.getDepth() + border;
   }

   /**
    * Generate PostScript text for the given box which
    * includes additional rmoveto operators for the left
    * and right border.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      StringBuffer result = new StringBuffer("");
      if (border > 0) {
	 result.append(((double) border / 1000) + " 0 rmoveto");
      }
      result.append(item.genPostScript(context));
      if (border > 0) {
	 result.append(((double) border / 1000) + " 0 rmoveto");
      }
      return result;
   }
} // class BorderedItem
