package de.uniulm.mathematik.typo.items;

/**
 * Hyphenations are flagged penalty items that, if used as a breakpoint,
 * require a box to be inserted.
 */
public class Hyphenation extends Penalty {
   private Item hyphen;

   /**
    * Construct a hyphenation item with a penalty value of 1.
    * @param hyphen insert this item, if used as a breakpoint.
    */
   public Hyphenation(Item hyphen) {
      super(1, true);
      assert(hyphen != null);
      this.hyphen = hyphen;
   }

   /**
    * Construct a hyphenation item with the given penalty value.
    * @param penalty penalty value which is usually positive.
    * @param hyphen item representing the hyphen, must not be null.
    */
   public Hyphenation(int penalty, Item hyphen) {
      super(penalty, true);
      assert(hyphen != null);
      this.hyphen = hyphen;
   }

   /**
    * Return an item that is to be inserted at the end of
    * the upper line if a line is to be split at this point.
    * Null may be returned if there is nothing to be inserted
    * or if this is not a penalty.
    */
   public Item getHyphen() {
      return hyphen;
   }
} // class Hyphenation
