package de.uniulm.mathematik.typo.items;

/**
 * Instances of this class represent widths that can be possibly
 * stretched or shrank.
 */
public class Width {
   private int width;
   private int shrinkability;
   private int stretchability;

   private int intoRange(int value, int min, int max) {
      if (value > max) {
	 return max;
      } else if (value < min) {
	 return min;
      } else {
	 return value;
      }
   }

   private void checkRanges() {
      width = intoRange(width, -Item.INFINITY, Item.INFINITY);
      shrinkability = intoRange(shrinkability, 0, width);
      stretchability = intoRange(stretchability, 0, Item.INFINITY);
   }

   /**
    * Construct an initially zero-valued width.
    */
   public Width() {
      width = 0; shrinkability = 0; stretchability = 0;
   }

   /**
    * Construct a width whose initial value is taken from the given item.
    */
   public Width(Item item) {
      this();
      this.add(item);
   }

   /**
    * Construct a width that is cloned from the given width.
    */
   public Width(Width w) {
      width = w.getWidth();
      shrinkability = w.getShrinkability();
      stretchability = w.getStretchability();
   }

   /**
    * Increment the width by the width of the given item.
    */
   public void add(Item item) {
      width += item.getWidth();
      shrinkability += item.getShrinkability();
      stretchability += item.getStretchability();
      checkRanges();
   }

   /**
    * Increment the width by the given width.
    */
   public void add(Width w) {
      width += w.getWidth();
      shrinkability += w.getShrinkability();
      stretchability += w.getStretchability();
      checkRanges();
   }

   /**
    * Return the current width.
    */
   public int getWidth() {
      return width;
   }

   /**
    * Return how much this width can be maximally shrank.
    */
   public int getShrinkability() {
      return shrinkability;
   }

   /**
    * Return how much this width can be maximally stretched.
    */
   public int getStretchability() {
      return stretchability;
   }
} // class Width
